Retrieves the Bible data filtered by the specified language and testament.
get_bible_version(language, testament)A data frame containing the Bible data corresponding to the selected language and testament.
A character string specifying the language of the Bible.
Must be one of "English", "Hebrew", or "Greek".
A character string specifying the testament. This input is standardized using
standardize_testament() and should typically be "Old Testament", "New Testament",
or "Both".
This function filters the underlying Bible dataset based on the specified language and testament.
For English, it divides the dataset into Old and New Testaments by using predefined book ranges from the
rasb_bible dataset. For Hebrew and Greek, it refers to the old_testament and new_testament
datasets respectively, and will produce an error if an unsupported combination is requested.